diff --git a/CODE_OF_CONDUCT.md b/CODE_OF_CONDUCT.md
deleted file mode 100644
index b0a0ab2f2..000000000
--- a/CODE_OF_CONDUCT.md
+++ /dev/null
@@ -1,5 +0,0 @@
-# Code of Conduct
-
-The code of conduct for this project can be found at https://swift.org/code-of-conduct.
-
-
diff --git a/src/App.vue b/src/App.vue
index 1115d50a4..742765f74 100644
--- a/src/App.vue
+++ b/src/App.vue
@@ -14,7 +14,9 @@
:class="{ fromkeyboard: fromKeyboard, hascustomheader: hasCustomHeader }"
>
- {{ $t('accessibility.skip-navigation') }}
+
+ {{ $t('accessibility.skip-navigation') }}
+
diff --git a/src/components/Article.vue b/src/components/Article.vue
index ff8894798..f95bbc71e 100644
--- a/src/components/Article.vue
+++ b/src/components/Article.vue
@@ -18,7 +18,7 @@
:rootReference="hierarchy.reference"
:identifierUrl="identifierUrl"
/>
-
+
{
if (node.type === BlockType.paragraph) {
return `${text}\n`;
}
+ if (node.type === InlineType.codeVoice) {
+ return `${text}${node.code}`;
+ }
if (node.type === InlineType.text) {
return `${text}${node.text}`;
}
+ if (node.type === InlineType.reference) {
+ const title = references[node.identifier]?.title ?? '';
+ return `${text}${title}`;
+ }
return text;
}, '').trim();
},
diff --git a/src/components/ContentNode/Reference.vue b/src/components/ContentNode/Reference.vue
index 8d275ce5c..d9dbe19ae 100644
--- a/src/components/ContentNode/Reference.vue
+++ b/src/components/ContentNode/Reference.vue
@@ -54,6 +54,9 @@ export default {
name: 'Reference',
computed: {
isInternal({ url }) {
+ if (!url) {
+ return false;
+ }
if (!url.startsWith('/') && !url.startsWith('#')) {
// If the URL has a scheme, it's not an internal link.
return false;
@@ -92,7 +95,7 @@ export default {
props: {
url: {
type: String,
- required: true,
+ required: false,
},
kind: {
type: String,
diff --git a/src/components/ContentNode/ReferenceExternal.vue b/src/components/ContentNode/ReferenceExternal.vue
index f24e4b42f..732e180d7 100644
--- a/src/components/ContentNode/ReferenceExternal.vue
+++ b/src/components/ContentNode/ReferenceExternal.vue
@@ -9,7 +9,7 @@
-->
-
+
@@ -19,7 +19,7 @@ export default {
props: {
url: {
type: String,
- required: true,
+ required: false,
},
isActive: {
type: Boolean,
diff --git a/src/components/ContentNode/ReferenceInternal.vue b/src/components/ContentNode/ReferenceInternal.vue
index bf55aee85..955119eeb 100644
--- a/src/components/ContentNode/ReferenceInternal.vue
+++ b/src/components/ContentNode/ReferenceInternal.vue
@@ -9,7 +9,7 @@
-->
-
+
@@ -19,7 +19,7 @@ export default {
props: {
url: {
type: String,
- required: true,
+ required: false,
},
isActive: {
type: Boolean,
diff --git a/src/components/DocumentationLayout.vue b/src/components/DocumentationLayout.vue
index a24a770f0..f53dfe20c 100644
--- a/src/components/DocumentationLayout.vue
+++ b/src/components/DocumentationLayout.vue
@@ -19,8 +19,8 @@
:displaySidenav="enableNavigator"
@toggle-sidenav="handleToggleSidenav"
>
-
-
+
+
-
-
+
+
diff --git a/src/components/DocumentationTopic/ContentTable.vue b/src/components/DocumentationTopic/ContentTable.vue
index bdc1fa685..79e604c2a 100644
--- a/src/components/DocumentationTopic/ContentTable.vue
+++ b/src/components/DocumentationTopic/ContentTable.vue
@@ -1,7 +1,7 @@
+
+
+
+
+
+
+
+
diff --git a/src/components/DocumentationTopic/PrimaryContent/DeclarationList.vue b/src/components/DocumentationTopic/PrimaryContent/DeclarationList.vue
index 0461e3808..a06b75d5b 100644
--- a/src/components/DocumentationTopic/PrimaryContent/DeclarationList.vue
+++ b/src/components/DocumentationTopic/PrimaryContent/DeclarationList.vue
@@ -1,7 +1,7 @@
+
+ {{text}}
+
diff --git a/src/components/DocumentationTopic.vue b/src/components/DocumentationTopic.vue
index e5ca984fb..6a20c295e 100644
--- a/src/components/DocumentationTopic.vue
+++ b/src/components/DocumentationTopic.vue
@@ -15,7 +15,7 @@
>
-
@@ -154,6 +154,11 @@
v-if="seeAlsoSections && !enableMinimized"
:sections="seeAlsoSections"
/>
+
@@ -778,7 +783,7 @@ $space-size: 15px;
}
}
-#main {
+#app-main {
outline-style: none;
height: 100%;
@@ -831,6 +836,11 @@ $space-size: 15px;
--aside-border-radius: 6px;
--code-border-radius: 6px;
+ &:not(.declarations-container) {
+ padding-left: 1.4rem;
+ padding-right: 1.4rem;
+ }
+
.description {
margin-bottom: 1.5em;
}
@@ -904,11 +914,6 @@ $space-size: 15px;
}
}
-.full-width-container .doc-content .minimized-container {
- padding-left: 1.4rem;
- padding-right: 1.4rem;
-}
-
:deep() {
.no-primary-content {
// remove border-top for first section of the page
@@ -952,7 +957,7 @@ $space-size: 15px;
min-width: 0;
width: 100%;
// only render border on declaration list menu
// when there are no content sections afterwards at all
.container:only-child {
.declaration-list-menu:last-child::before {
@@ -961,6 +966,7 @@ $space-size: 15px;
border-top-width: var(--content-table-title-border-width, 1px);
content: '';
display: block;
+ margin-bottom: $section-spacing-single-side;
}
}
@@ -952,7 +957,7 @@ $space-size: 15px;
min-width: 0;
width: 100%;
- // only render border on declaration list menu
+ // only render border and bottom margin on declaration list menu
// when there are no content sections afterwards at all
.container:only-child {